@@ -7,6 +7,6 @@ __license__ = 'BSD'
 
 
 from .bind import WeixinClientError, WeixinAPIError
-from .client import WeixinAPI, WeixinMpAPI
+from .client import WeixinAPI, WeixinMpAPI, WXAPPAPI
 from .response import WXResponse
 from .reply import WXReply
