@@ -6,8 +6,9 @@
 """
 # TODO 重构加密解密
 
+from imp import reload
+
 import base64
-import string
 import random
 import hashlib
 import time
@@ -16,8 +17,12 @@ from Crypto.Cipher import AES
 import xml.etree.cElementTree as ET
 import sys
 import socket
+
 reload(sys)
-import ierror
+
+from .ierror import *
+
+from weixin.helper import smart_bytes, safe_char
 
 
 class FormatException(Exception):
@@ -44,10 +49,10 @@ class SHA1:
             sortlist = [token, timestamp, nonce, encrypt]
             sortlist.sort()
             sha = hashlib.sha1()
-            sha.update("".join(sortlist))
-            return ierror.WXBizMsgCrypt_OK, sha.hexdigest()
+            sha.update(str("".join(sortlist)).encode('utf-8'))
+            return WXBizMsgCrypt_OK, sha.hexdigest()
         except Exception:
-            return ierror.WXBizMsgCrypt_ComputeSignature_Error, None
+            return WXBizMsgCrypt_ComputeSignature_Error, None
 
 
 class XMLParse:
@@ -72,9 +77,9 @@ class XMLParse:
             xml_tree = ET.fromstring(xmltext)
             encrypt = xml_tree.find("Encrypt")
             touser_name = xml_tree.find("ToUserName")
-            return ierror.WXBizMsgCrypt_OK, encrypt.text, touser_name.text
+            return WXBizMsgCrypt_OK, encrypt.text, touser_name.text
         except Exception:
-            return ierror.WXBizMsgCrypt_ParseXml_Error, None, None
+            return WXBizMsgCrypt_ParseXml_Error, None, None
 
     def generate(self, encrypt, signature, timestamp, nonce):
         """生成xml消息
@@ -110,7 +115,7 @@ class PKCS7Encoder():
         if amount_to_pad == 0:
             amount_to_pad = self.block_size
         # 获得补位所用的字符
-        pad = chr(amount_to_pad)
+        pad = smart_bytes(chr(amount_to_pad))
         return text + pad * amount_to_pad
 
     def decode(self, decrypted):
@@ -139,8 +144,8 @@ class Prpcrypt(object):
         @return: 加密得到的字符串
         """
         # 16位随机字符串添加到明文开头
-        text = self.get_random_str() + struct.pack(
-            "I", socket.htonl(len(text))) + text + appid
+        pack_str = struct.pack(b"I", socket.htonl(len(text)))
+        text = smart_bytes(self.get_random_str()) + pack_str + smart_bytes(text) + smart_bytes(appid)
         # 使用自定义的填充方式对明文进行补位填充
         pkcs7 = PKCS7Encoder()
         text = pkcs7.encode(text)
@@ -149,9 +154,9 @@ class Prpcrypt(object):
         try:
             ciphertext = cryptor.encrypt(text)
             # 使用BASE64对加密后的字符串进行编码
-            return ierror.WXBizMsgCrypt_OK, base64.b64encode(ciphertext)
+            return WXBizMsgCrypt_OK, base64.b64encode(ciphertext)
         except Exception:
-            return ierror.WXBizMsgCrypt_EncryptAES_Error, None
+            return WXBizMsgCrypt_EncryptAES_Error, None
 
     def decrypt(self, text, appid):
         """对解密后的明文进行补位删除
@@ -163,30 +168,30 @@ class Prpcrypt(object):
             # 使用BASE64对密文进行解码，然后AES-CBC解密
             plain_text = cryptor.decrypt(base64.b64decode(text))
         except Exception:
-            return ierror.WXBizMsgCrypt_DecryptAES_Error, None
+            return WXBizMsgCrypt_DecryptAES_Error, None
         try:
-            pad = ord(plain_text[-1])
+            pad = plain_text[-1]
             # 去掉补位字符串
             # pkcs7 = PKCS7Encoder()
             # plain_text = pkcs7.encode(plain_text)
-            #  去除16位随机字符串
+            # 去除16位随机字符串
             content = plain_text[16:-pad]
-            xml_len = socket.ntohl(struct.unpack("I", content[:4])[0])
+            xml_len = socket.ntohl(struct.unpack(b"I", content[:4])[0])
             xml_content = content[4:xml_len+4]
-            from_appid = content[xml_len+4:]
+            from_appid = smart_bytes(content[xml_len+4:])
         except Exception:
-            return ierror.WXBizMsgCrypt_IllegalBuffer, None
-        if from_appid != appid:
-            return ierror.WXBizMsgCrypt_ValidateAppid_Error, None
+            return WXBizMsgCrypt_IllegalBuffer, None
+        if from_appid != smart_bytes(appid):
+            return WXBizMsgCrypt_ValidateAppid_Error, None
         return 0, xml_content
 
     def get_random_str(self):
         """ 随机生成16位字符串
         @return: 16位字符串
         """
-        rule = string.letters + string.digits
-        str = random.sample(rule, 16)
-        return "".join(str)
+        str_list = random.sample(safe_char[:-4], 16)
+        sl = [chr(s) for s in str_list]
+        return "".join(sl)
 
 
 class WXBizMsgCrypt(object):
@@ -244,7 +249,7 @@ class WXBizMsgCrypt(object):
         if ret != 0:
             return ret, None
         if not signature == sMsgSignature:
-            return ierror.WXBizMsgCrypt_ValidateSignature_Error, None
+            return WXBizMsgCrypt_ValidateSignature_Error, None
         pc = Prpcrypt(self.key)
         ret, xml_content = pc.decrypt(encrypt, self.appid)
         return ret, xml_content
